pub struct ReleaseRecord {
pub resource_id: ResourceId,
pub kind: ResourceKind,
pub attempt: u32,
pub outcome: ReleaseOutcome,
pub rollback: bool,
}Expand description
One release attempt, including internal rollback after an injected post-create fault.
Fields
resource_id: ResourceIdkind: ResourceKindattempt: u32outcome: ReleaseOutcomerollback: boolTrait Implementations
Sourceimpl Clone for ReleaseRecord
impl Clone for ReleaseRecord
Sourcefn clone(&self) -> ReleaseRecord
fn clone(&self) -> ReleaseRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReleaseRecord
Sourceimpl Debug for ReleaseRecord
impl Debug for ReleaseRecord
impl Eq for ReleaseRecord
Sourceimpl PartialEq for ReleaseRecord
impl PartialEq for ReleaseRecord
Sourcefn eq(&self, other: &ReleaseRecord) -> bool
fn eq(&self, other: &ReleaseRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReleaseRecord